/**
 * @file
 */

(function ($, Drupal, once) {
  'use strict';

  Drupal.behaviors.seoPreview = {
    attach: function (context) {

      $(context).on('seoPreviewOpen', function (event, args) {
        /* global YoastSeoDrupal */
        const DrupalSeoPreview = new YoastSeoDrupal();
        const snippetTarget = $('#yoast-seo-preview-snippet', context).get(0);
        const throbber = $('<div class="ajax-progress ajax-progress-throbber"></div>');
        throbber.append('<div class="throbber">&nbsp;</div>');

        const snippetPreview = new DrupalSeoPreview.SnippetPreview({
          targetElement: snippetTarget,
          baseURL: args['baseURL'],
          data: {
            title: args['title'],
            urlPath: args['urlPath'],
            metaDesc: args['metaDesc']
          }
        });

        // Disable snippet editor events.
        snippetPreview.bindEvents = function () {};

        $(snippetTarget).after(throbber);

        const app = new DrupalSeoPreview.App({
          snippetPreview: snippetPreview,
          targets: {
            output: 'yoast-seo-preview-output'
          },
          callbacks: {
            getData: function () {
              return {
                keyword: args['keyword'],
                text: args['text']
              };
            },
            updatedKeywordsResults: function () {
              throbber.remove();
            }
          }
        });

        app.refresh();

      });
    }
  };

}(jQuery, Drupal, once));
